package java.awt;

import java.awt.font.FontRenderContext;
import java.util.Map;
import java.awt.font.GlyphVector;
import java.text.AttributedCharacterIterator;
import java.awt.image.renderable.RenderableImage;
import java.awt.image.RenderedImage;
import java.awt.image.BufferedImageOp;
import java.awt.image.BufferedImage;
import java.awt.image.ImageObserver;
import java.awt.geom.AffineTransform;

public abstract class Graphics2D extends Graphics
{
    protected Graphics2D() {
    }
    
    @Override
    public void draw3DRect(int n, int n2, int n3, int n4, boolean b) {
        Paint paint = this.getPaint();
        Color color = this.getColor();
        Color brighter = color.brighter();
        Color darker = color.darker();
        this.setColor(b ? brighter : darker);
        this.fillRect(n, n2, 1, n4 + 1);
        this.fillRect(n + 1, n2, n3 - 1, 1);
        this.setColor(b ? darker : brighter);
        this.fillRect(n + 1, n2 + n4, n3, 1);
        this.fillRect(n + n3, n2, 1, n4);
        this.setPaint(paint);
    }
    
    @Override
    public void fill3DRect(int n, int n2, int n3, int n4, boolean b) {
        Paint paint = this.getPaint();
        Color color = this.getColor();
        Color brighter = color.brighter();
        Color darker = color.darker();
        if (!b) {
            this.setColor(darker);
        }
        else if (paint != color) {
            this.setColor(color);
        }
        this.fillRect(n + 1, n2 + 1, n3 - 2, n4 - 2);
        this.setColor(b ? brighter : darker);
        this.fillRect(n, n2, 1, n4);
        this.fillRect(n + 1, n2, n3 - 2, 1);
        this.setColor(b ? darker : brighter);
        this.fillRect(n + 1, n2 + n4 - 1, n3 - 1, 1);
        this.fillRect(n + n3 - 1, n2, 1, n4 - 1);
        this.setPaint(paint);
    }
    
    public abstract void draw(Shape p0);
    
    public abstract boolean drawImage(Image p0, AffineTransform p1, ImageObserver p2);
    
    public abstract void drawImage(BufferedImage p0, BufferedImageOp p1, int p2, int p3);
    
    public abstract void drawRenderedImage(RenderedImage p0, AffineTransform p1);
    
    public abstract void drawRenderableImage(RenderableImage p0, AffineTransform p1);
    
    @Override
    public abstract void drawString(String p0, int p1, int p2);
    
    public abstract void drawString(String p0, float p1, float p2);
    
    @Override
    public abstract void drawString(AttributedCharacterIterator p0, int p1, int p2);
    
    public abstract void drawString(AttributedCharacterIterator p0, float p1, float p2);
    
    public abstract void drawGlyphVector(GlyphVector p0, float p1, float p2);
    
    public abstract void fill(Shape p0);
    
    public abstract boolean hit(Rectangle p0, Shape p1, boolean p2);
    
    public abstract GraphicsConfiguration getDeviceConfiguration();
    
    public abstract void setComposite(Composite p0);
    
    public abstract void setPaint(Paint p0);
    
    public abstract void setStroke(Stroke p0);
    
    public abstract void setRenderingHint(RenderingHints.Key p0, Object p1);
    
    public abstract Object getRenderingHint(RenderingHints.Key p0);
    
    public abstract void setRenderingHints(Map<?, ?> p0);
    
    public abstract void addRenderingHints(Map<?, ?> p0);
    
    public abstract RenderingHints getRenderingHints();
    
    @Override
    public abstract void translate(int p0, int p1);
    
    public abstract void translate(double p0, double p1);
    
    public abstract void rotate(double p0);
    
    public abstract void rotate(double p0, double p1, double p2);
    
    public abstract void scale(double p0, double p1);
    
    public abstract void shear(double p0, double p1);
    
    public abstract void transform(AffineTransform p0);
    
    public abstract void setTransform(AffineTransform p0);
    
    public abstract AffineTransform getTransform();
    
    public abstract Paint getPaint();
    
    public abstract Composite getComposite();
    
    public abstract void setBackground(Color p0);
    
    public abstract Color getBackground();
    
    public abstract Stroke getStroke();
    
    public abstract void clip(Shape p0);
    
    public abstract FontRenderContext getFontRenderContext();
}
